const NOINDEX: &str = "noindex is set to true, FYI.";
const NO_TITLE_ARGUMENT: &str = "Sorry, but you can't provide the --title argument without a title...";
const NO_TITLE_ARGUMENT_2: &str = "Sorry, but you need to provide the --title argument";
use std::io;
use std::io::Write;
use std::collections::HashMap;

extern crate clap;
use clap::{Arg, App, SubCommand};

fn main() {
    let matches = App::new("intern")
        .version("1.0")
        .author("TheTechRobo")
        .about("Creates a command for the ia cli")
        .arg(Arg::with_name("IDENTIFIER")
             .help("Sets the item identifier")
             .required(true)
             .index(1))
        .arg(Arg::with_name("TITLE")
             .help("Item title")
             .required(true)
             .index(2))
        .arg(Arg::with_name("TYPE")
             .help("Type of item (one of: web text wiki none)")
             .required(true)
             .index(3))
        .arg(Arg::with_name("FILES")
             .help("Files to upload")
             .required(true)
             .multiple(true)
             .index(4))
        .arg(Arg::with_name("metadata")
             .short('m')
             .long("metadata")
             .multiple(true)
             .takes_value(true)
             .help("Add Metadata"))
        .arg(Arg::with_name("options")
             .short('i')
             .long("extra-options")
             .multiple(true)
             .takes_value(true)
             .help("Arguments to pass to ia"))
        .get_matches();
    let raw_metadata: Vec<&str> = match matches.values_of("metadata") {
        Some(args) => args.collect(),
        None => vec!(),
    };
    let raw_options: Vec<&str> = match matches.values_of("options") {
        Some(args) => args.collect(),
        None => vec!(),
    };
    //println!("{:?}", raw_metadata);
    let item_type = matches.value_of("TYPE").unwrap();
    let title = matches.value_of("TITLE").unwrap();
    let identifier = matches.value_of("IDENTIFIER").unwrap();
    let mut metadata = HashMap::new();
    if item_type == "web" {
        metadata.insert(
            "mediatype".to_string(),
            "web".to_string()
            );
    }
    else if item_type == "text" {
        metadata.insert(
            "mediatype".to_string(),
            "texts".to_string(),
            );
    }
    else if item_type == "wiki" {
        metadata.insert(
            "mediatype".to_string(),
            "texts".to_string(),
            );
        metadata.insert(
            "subject".to_string(),
            "MediaWiki; wiki; wikiteam".to_string(),
            );
    }
    else if item_type == "none" {
    }
    else {
        unimplemented!("Unsupported item type. Currently supported; web texts wiki none");
    }
    metadata.insert(
        "title".to_string(),
        title.to_string(),
        );
    for meta in raw_metadata {
        let meta_: Vec<&str> = meta.split(":").collect();
        if metadata.contains_key(meta_[0]) {
            metadata.remove(meta_[0]);
        }
        metadata.insert(
            meta_[0].to_string(),
            meta_[1].to_string()
            );
    }

    // Setup variables for printing
    let files: Vec<&str> = matches.values_of("FILES").unwrap().collect();
    let tool = "ia upload";
    let mut options_files = "".to_string();
    let mut options_metadata = "".to_string();
    let mut extra_options = "".to_string();
    for file in files {
        options_files = format!("{} {}", options_files, file);
    }
    for option in raw_options {
        extra_options = format!("{} {}", extra_options, option);
    }
    for (key, value) in &metadata {
        options_metadata = format!("{} --metadata \"{}:{}\"", options_metadata, key, value);
    }
    println!("{} {} {} {} {}", tool.trim(), identifier.trim(), options_files.trim(), options_metadata.trim(), extra_options.trim());

    //println!("{}", identifier);
}
